@@ -1068,12 +1068,16 @@ def run_transform(run_options, **kwargs):
 
     service_name = run_options.pop('service_name')
     run_location = run_options.pop('run_location')
-    if (run_location == "inline"):
+        if (run_location == "inline"):
+        experiment_id = None
         if (parent_run_id != None):
             nes = True
+            if ('experiment_id' in run_options):
+                experiment_id = str(run_options['experiment_id'])
         else:
             nes = False
-        with start_run(nested=nes) as run:
+        print("run_transform: experiment_id is " + experiment_id)
+        with start_run(nested=nes, experiment_id=experiment_id) as run:
             xobjects = run_transform_inline(service_name, run.info.run_id,
                     input_data_spec, xformname, **kwargs)
             return run.info.run_id
@@ -1098,7 +1102,13 @@ def run_transforms(transforms):
         else:
             return run_transform(transform['run_options'])
 
-    run = start_run()
+    if ('experiment_id' in transforms[0]['run_options']):
+        experiment_id = str(transforms[0]['run_options']['experiment_id'])
+        print("run_transforms: experiment_id is specified as " + experiment_id)
+        run = start_run(experiment_id = experiment_id)
+    else:
+        print("run_transforms: experiment_id is not specified")
+        run = start_run()
     parent_run_id = run.info.run_id
     print('parent_run_id = ' + str(parent_run_id))
 
